===============
Getting started
===============

In this section, there are multiple tutorials and introductions.

Some of them are also available in the
`zfit youtube channel <https://www.youtube.com/channel/UC_IOWLYdQSkWr54K-o8BTCA>`_

.. toctree::
    :maxdepth: 1

    installation
    5_minutes_to_zfit
    intro/index
    models/index
    guides
    examples
